==> ipp-crypto_1.3.0.orig.tar.xz: ipp-crypto-1.3.0/sources/ippcp/hash/sha512/pcphashmethod_sha512_256_ni.c <==
/*************************************************************************
* Copyright (C) 2024 Intel Corporation
*
* Licensed under the Apache License,  Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* 	http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law  or agreed  to  in  writing,  software
* distributed under  the License  is  distributed  on  an  "AS IS"  BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the  specific  language  governing  permissions  and
* limitations under the License.
*************************************************************************/

/*
//
//  Purpose:
//     Cryptography Primitive.
//     SHA512/256 message digest
//
//  Contents:
//        ippsHashMethod_SHA512_256_NI()
//
*/

#include "owndefs.h"
#include "owncp.h"
#include "hash/pcphash.h"
#include "hash/pcphash_rmf.h"
#include "pcptool.h"
#include "hash/sha512/pcpsha512stuff.h"

/*F*
//    Name: ippsHashMethod_SHA512_256_NI
//
// Purpose: Return SHA512/256 method.
//
// Returns:
//          Pointer to SHA512/256 hash-method.
//
*F*/

IPPFUN(const IppsHashMethod*, ippsHashMethod_SHA512_256_NI, (void))
{
#if (_SHA512_ENABLING_ == _FEATURE_TICKTOCK_ || _SHA512_ENABLING_ == _FEATURE_ON_)
    static IppsHashMethod method = { ippHashAlg_SHA512_256,
                                     IPP_SHA256_DIGEST_BITSIZE / 8,
                                     MBS_SHA512,
                                     MLR_SHA512,
                                     IPP_SHA512_STATE_BYTESIZE,
                                     NULL,
                                     NULL,
                                     NULL,
                                     NULL };

    // don't merge `method` initialization with function pointers assignment
    // to prevent relocations (indirect calls) to be generated in the binary
    method.hashInit   = sha512_256_hashInit;
    method.hashUpdate = sha512_hashUpdate_ni;
    method.hashOctStr = sha512_256_hashOctString;
    method.msgLenRep  = sha512_msgRep;

    return &method;
#else
    return NULL;
#endif
}

==> ipp-crypto_1.4.0.orig.tar.xz: ipp-crypto-1.4.0/sources/ippcp/hash/sha512/pcphashmethod_sha512_224_ni.c <==
/*************************************************************************
* Copyright (C) 2024 Intel Corporation
*
* Licensed under the Apache License,  Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* 	http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law  or agreed  to  in  writing,  software
* distributed under  the License  is  distributed  on  an  "AS IS"  BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the  specific  language  governing  permissions  and
* limitations under the License.
*************************************************************************/

/*
//
//  Purpose:
//     Cryptography Primitive.
//     SHA512/224 message digest
//
//  Contents:
//        ippsHashMethod_SHA512_224_NI()
//
*/

#include "owndefs.h"
#include "owncp.h"
#include "hash/pcphash.h"
#include "hash/pcphash_rmf.h"
#include "pcptool.h"
#include "hash/sha512/pcpsha512stuff.h"

/*F*
//    Name: ippsHashMethod_SHA512_224_NI
//
// Purpose: Return SHA512/224 method.
//
// Returns:
//          Pointer to SHA512/224 hash-method.
//
*F*/

IPPFUN(const IppsHashMethod*, ippsHashMethod_SHA512_224_NI, (void))
{
#if (_SHA512_ENABLING_ == _FEATURE_TICKTOCK_ || _SHA512_ENABLING_ == _FEATURE_ON_)
    /* Prevents re-initialization for better multi-threaded/repeated call performance */
    static volatile int isInitialized = 0;

    static IppsHashMethod method = { ippHashAlg_SHA512_224,
                                     IPP_SHA224_DIGEST_BITSIZE / 8,
                                     MBS_SHA512,
                                     MLR_SHA512,
                                     IPP_SHA512_STATE_BYTESIZE,
                                     NULL,
                                     NULL,
                                     NULL,
                                     NULL };
    if (isInitialized) {
        CP_PREVENT_REORDER();
        return &method;
    }

    // don't merge `method` initialization with function pointers assignment
    // to prevent relocations (indirect calls) to be generated in the binary
    method.hashInit   = sha512_224_hashInit;
    method.hashUpdate = sha512_hashUpdate_ni;
    method.hashOctStr = sha512_224_hashOctString;
    method.msgLenRep  = sha512_msgRep;

    CP_PREVENT_REORDER();
    isInitialized = 1;

    return &method;
#else
    return NULL;
#endif
}
